==> apache-ranger-1.1.0.tar.gz: apache-ranger-1.1.0/security-admin/src/main/webapp/scripts/model_bases/UserPermissionBase.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


define(function(require){
	'use strict';

	var XABaseModel	= require('models/XABaseModel');
	var XAGlobals	= require('utils/XAGlobals');

	var UserPermissionBase = XABaseModel.extend(
	/** @lends UserPermissionBase.prototype */
	{
		urlRoot: XAGlobals.baseURL + 'permissions',

		defaults: {},

		serverSchema : {
			"id" : {
				"dataType" : "Long"
			}
		},


		idAttribute: 'id',

		/**
		 * UserPermissionBase initialize method
		 * @augments XABaseModel
		 * @constructs
		 */
		initialize: function() {
			this.modelName = 'UserPermission';
			//this.bind("error", XAUtils.defaultErrorHandler);
			this.bindErrorEvents();
		},
	}, {
		// static class members
	});

    return UserPermissionBase;

});

==> apache-ranger-2.6.0.tar.gz: apache-ranger-2.6.0/security-admin/src/main/webapp/scripts/model_bases/UserPermissionBase.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


define(function(require){
	'use strict';

	var XABaseModel	= require('models/XABaseModel');
	var XAGlobals	= require('utils/XAGlobals');

	var UserPermissionBase = XABaseModel.extend(
	/** @lends UserPermissionBase.prototype */
	{
                urlRoot: XAGlobals.baseURL + 'permissions/models',

		defaults: {},

		serverSchema : {
			"id" : {
				"dataType" : "Long"
			}
		},


		idAttribute: 'id',

		/**
		 * UserPermissionBase initialize method
		 * @augments XABaseModel
		 * @constructs
		 */
		initialize: function() {
			this.modelName = 'UserPermission';
			//this.bind("error", XAUtils.defaultErrorHandler);
			this.bindErrorEvents();
		},
	}, {
		// static class members
	});

    return UserPermissionBase;

});
